"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const modules_1 = require("../lib/modules");
function getPages(context) {
    return __awaiter(this, void 0, void 0, function* () {
        const AppScripts = modules_1.load('@ionic/app-scripts');
        const pages = yield AppScripts.getNgModules(context, ['page', 'component']);
        const ngModuleSuffix = yield AppScripts.getStringPropertyValue('IONIC_NG_MODULE_FILENAME_SUFFIX');
        return pages.map((page) => {
            return {
                fileName: path.basename(page.absolutePath, ngModuleSuffix),
                absolutePath: page.absolutePath,
                relativePath: path.relative(context.rootDir, page.absolutePath)
            };
        });
    });
}
exports.getPages = getPages;
function prompt(type, context) {
    return __awaiter(this, void 0, void 0, function* () {
        const inquirer = modules_1.load('inquirer');
        const usageQuestion = yield inquirer.prompt({
            type: 'confirm',
            name: 'usage',
            message: `Use this ${type} in more than one template?`
        });
        if (!usageQuestion.usage) {
            const fileChoices = yield getPages(context);
            const filteredChoices = fileChoices.map((file) => {
                return {
                    prettyName: path.dirname(file.relativePath),
                    fullName: file.relativePath
                };
            });
            const usagePlaces = yield inquirer.prompt({
                type: 'list',
                name: 'whereUsed',
                message: `Page or component that will be using this ${type}`,
                choices: filteredChoices.map((choiceObject) => {
                    return choiceObject.prettyName;
                })
            });
            const chosenPath = fileChoices.find((file) => {
                return path.dirname(file.relativePath) === usagePlaces.whereUsed;
            });
            return chosenPath.absolutePath;
        }
        else {
            return context.appNgModulePath;
        }
    });
}
exports.prompt = prompt;
function tabsPrompt() {
    return __awaiter(this, void 0, void 0, function* () {
        const tabNames = [];
        const inquirer = modules_1.load('inquirer');
        const howManyQuestion = yield inquirer.prompt({
            name: 'howMany',
            message: 'How many tabs?'
        });
        for (let i = 0; i < howManyQuestion.howMany; i++) {
            const nameQuestion = yield inquirer.prompt({
                name: 'tabName',
                message: 'Name of this tab:'
            });
            tabNames.push(nameQuestion.tabName);
        }
        return tabNames;
    });
}
exports.tabsPrompt = tabsPrompt;
